import type { Configuration, Diagnostic, PullDiagnosticsResult } from "@biomejs/wasm-nodejs";
import { Distribution } from "./wasm";
export type { Configuration, Diagnostic };
export { Distribution };
export interface FormatContentDebugOptions extends FormatContentOptions {
    /**
     * If `true`, you'll be able to inspect the IR of the formatter
     */
    debug: boolean;
}
export interface FormatContentOptions {
    /**
     * A virtual path of the file. You should add the extension,
     * so Biome knows how to parse the content
     */
    filePath: string;
    /**
     * The range where to format the content
     */
    range?: [number, number];
}
export interface FormatResult {
    /**
     * The new formatted content
     */
    content: string;
    /**
     * A series of errors encountered while executing an operation
     */
    diagnostics: Diagnostic[];
}
export interface FormatDebugResult {
    /**
     * The new formatted content
     */
    content: string;
    /**
     * A series of errors encountered while executing an operation
     */
    diagnostics: Diagnostic[];
    /**
     * The IR emitted by the formatter
     */
    ir: string;
}
export interface LintContentOptions {
    /**
     * A virtual path of the file. You should add the extension,
     * so Biome knows how to parse the content
     */
    filePath: string;
}
export interface BiomeCreate {
    distribution: Distribution;
}
export interface PrintDiagnosticsOptions {
    /**
     * The name of the file to print diagnostics for
     */
    filePath: string;
    /**
     * The content of the file the diagnostics were emitted for
     */
    fileSource: string;
    /**
     * Whether to print the diagnostics in verbose mode
     */
    verbose?: boolean;
}
export declare class Biome {
    private readonly module;
    private readonly workspace;
    private constructor();
    /**
     * It creates a new instance of the class {Biome}.
     */
    static create(options: BiomeCreate): Promise<Biome>;
    /**
     * Stop this instance of Biome
     *
     * After calling `shutdown()` on this object, it should be considered
     * unusable as calling any method on it will fail
     */
    shutdown(): void;
    /**
     * Allows to apply a custom configuration.
     *
     * If fails when the configuration is incorrect.
     *
     * @param configuration
     */
    applyConfiguration(configuration: Configuration): void;
    private withFile;
    formatContent(content: string, options: FormatContentOptions): FormatResult;
    formatContent(content: string, options: FormatContentDebugOptions): FormatDebugResult;
    /**
     * Lint the content of a file.
     *
     * @param {String} content The content to lint
     * @param {LintContentOptions} options Options needed when linting some content
     */
    lintContent(content: string, options: LintContentOptions): PullDiagnosticsResult;
    /**
     * Print a list of diagnostics to an HTML string.
     *
     * @param {Diagnostic[]} diagnostics The list of diagnostics to print
     * @param {PrintDiagnosticsOptions} options Options needed for printing the diagnostics
     */
    printDiagnostics(diagnostics: Diagnostic[], options: PrintDiagnosticsOptions): string;
}
//# sourceMappingURL=index.d.ts.map